<img src="https://github.com/art-egorov/svist4get/blob/main/docs/logo_256.png?raw=true" alt="drawing" width="150"/>

### Description

Svist4get is a simple bioinformatics tool for visualization of genomic signal tracks in user-defined genomic windows, either arbitrary selected by genomic coordinates or anchored to particular transcripts or genes.



**The detailed documentation is available at [Home Page](https://github.com/art-egorov/svist4get).**


### Reference

If you find svist4get useful, please cite:


Artyom A. Egorov, Ekaterina A. Sakharova, Aleksandra S. Anisimova, Sergey E. Dmitriev, Vadim N. Gladyshev and Ivan V. Kulakovskiy,  
**svist4get: a simple visualization tool for genomic tracks from sequencing experiments,**  
*BMC Bioinformatics, Volume 20, 2019, 113, [doi: 10.1186/s12859-019-2706-8](https://doi.org/10.1186/s12859-019-2706-8)*